@@ -10,7 +10,7 @@
 
 #define PODOFO_VERSION_MAJOR 0
 #define PODOFO_VERSION_MINOR 9
-#define PODOFO_VERSION_PATCH 3
+#define PODOFO_VERSION_PATCH 4
 
 /* PoDoFo configuration options */
 #define PODOFO_MULTI_THREAD
@@ -56,6 +56,3 @@
 #define PODOFO_HAVE_CPPUNIT
 #define PODOFO_HAVE_OPENSSL
 #define PODOFO_HAVE_LIBIDN
-
-/* Platform quirks */
-#define PODOFO_JPEG_RUNTIME_COMPATIBLE
